@@ -20,19 +20,19 @@ CREATE TABLE files
 );
 
 CREATE INDEX files_hash ON files (hash);
-CREATE INDEX files_path ON files (path);
 CREATE INDEX files_valid ON files (valid);
 
 CREATE TABLE data
 (
-    identity  BLOB PRIMARY KEY NOT NULL,
-    entity    BLOB             NOT NULL,
-    attribute VARCHAR          NOT NULL,
-    value     VARCHAR          NOT NULL,
-    immutable BOOLEAN          NOT NULL,
-    UNIQUE (entity, attribute, value)
+    identity        BLOB PRIMARY KEY NOT NULL,
+    entity          BLOB             NOT NULL,
+    attribute       VARCHAR          NOT NULL,
+    value_str       VARCHAR,
+    value_num       NUMERIC,
+    immutable       BOOLEAN          NOT NULL
 );
 
 CREATE INDEX data_entity ON data (entity);
 CREATE INDEX data_attribute ON data (attribute);
-CREATE INDEX data_value ON data (value);
+CREATE INDEX data_value_str ON data (value_str);
+CREATE INDEX data_value_num ON data (value_num);
