@@ -4,7 +4,6 @@ use std::sync::{Arc, Mutex};
 use anyhow::{anyhow, Result};
 use log::trace;
 use lru::LruCache;
-use serde_json::Value;
 use uuid::Uuid;
 
 use crate::addressing::{Address, Addressable};
@@ -95,26 +94,24 @@ impl PointerEntries for Vec<Entry> {
 }
 
 pub fn list_roots(connection: &UpEndConnection) -> Result<Vec<Address>> {
-    let all_directories: Vec<Entry> = connection.query(
-        Query::SingleQuery(QueryPart::Matches(EntryQuery {
+    let all_directories: Vec<Entry> =
+        connection.query(Query::SingleQuery(QueryPart::Matches(EntryQuery {
             entity: QueryComponent::Any,
             attribute: QueryComponent::Exact(IS_OF_TYPE_ATTR.to_string()),
             value: QueryComponent::Exact(EntryValue::Address(HIER_ADDR.clone())),
-        })),
-    )?;
+        })))?;
 
     // TODO: this is horrible
-    let directories_with_parents: Vec<Address> = connection.query(
-        Query::SingleQuery(QueryPart::Matches(EntryQuery {
+    let directories_with_parents: Vec<Address> = connection
+        .query(Query::SingleQuery(QueryPart::Matches(EntryQuery {
             entity: QueryComponent::Any,
             attribute: QueryComponent::Exact(HIER_HAS_ATTR.to_string()),
             value: QueryComponent::Any,
-        })),
-    )?
-    .extract_pointers()
-    .into_iter()
-    .map(|(_, val)| val)
-    .collect();
+        })))?
+        .extract_pointers()
+        .into_iter()
+        .map(|(_, val)| val)
+        .collect();
 
     Ok(all_directories
         .into_iter()
@@ -143,30 +140,26 @@ pub fn fetch_or_create_dir(
         _lock = FETCH_CREATE_LOCK.lock().unwrap();
     }
 
-    let matching_directories = connection.query(
-        Query::SingleQuery(QueryPart::Matches(EntryQuery {
+    let matching_directories = connection
+        .query(Query::SingleQuery(QueryPart::Matches(EntryQuery {
             entity: QueryComponent::Any,
             attribute: QueryComponent::Exact(String::from(LABEL_ATTR)),
-            value: QueryComponent::Exact(EntryValue::Value(Value::String(
-                directory.as_ref().clone(),
-            ))),
-        })),
-    )?
-    .into_iter()
-    .map(|e: Entry| e.entity);
+            value: QueryComponent::Exact(EntryValue::String(directory.as_ref().clone())),
+        })))?
+        .into_iter()
+        .map(|e: Entry| e.entity);
 
     let parent_has: Vec<Address> = match parent.clone() {
-        Some(parent) => connection.query(
-            Query::SingleQuery(QueryPart::Matches(EntryQuery {
+        Some(parent) => connection
+            .query(Query::SingleQuery(QueryPart::Matches(EntryQuery {
                 entity: QueryComponent::Exact(parent),
                 attribute: QueryComponent::Exact(String::from(HIER_HAS_ATTR)),
                 value: QueryComponent::Any,
-            })),
-        )?
-        .extract_pointers()
-        .into_iter()
-        .map(|(_, val)| val)
-        .collect(),
+            })))?
+            .extract_pointers()
+            .into_iter()
+            .map(|(_, val)| val)
+            .collect(),
         None => list_roots(connection)?,
     };
 
@@ -188,7 +181,7 @@ pub fn fetch_or_create_dir(
                 let directory_entry = Entry {
                     entity: new_directory_address.clone(),
                     attribute: String::from(LABEL_ATTR),
-                    value: EntryValue::Value(Value::String(directory.as_ref().clone())),
+                    value: EntryValue::String(directory.as_ref().clone()),
                 };
                 connection.insert_entry(directory_entry)?;
 
@@ -271,6 +264,7 @@ pub fn initialize_hier(connection: &UpEndConnection) -> Result<()> {
     connection.insert_entry(Entry::try_from(&*HIER_INVARIANT)?)?;
     upend_insert_addr!(connection, HIER_ADDR, IS_OF_TYPE_ATTR, TYPE_ADDR)?;
     upend_insert_val!(connection, HIER_ADDR, TYPE_HAS_ATTR, HIER_HAS_ATTR)?;
+    upend_insert_val!(connection, HIER_ADDR, LABEL_ATTR, "Group")?;
     Ok(())
 }
 
@@ -329,21 +323,11 @@ mod tests {
         let open_result = UpEndDatabase::open(&temp_dir, None, true).unwrap();
         let connection = open_result.db.connection().unwrap();
 
-        let foo_result = fetch_or_create_dir(
-            &connection,
-            None,
-            UNode("foo".to_string()),
-            true,
-        );
+        let foo_result = fetch_or_create_dir(&connection, None, UNode("foo".to_string()), true);
         assert!(foo_result.is_ok());
         let foo_result = foo_result.unwrap();
 
-        let bar_result = fetch_or_create_dir(
-            &connection,
-            None,
-            UNode("bar".to_string()),
-            true,
-        );
+        let bar_result = fetch_or_create_dir(&connection, None, UNode("bar".to_string()), true);
         assert!(bar_result.is_ok());
         let bar_result = bar_result.unwrap();
 
@@ -359,11 +343,7 @@ mod tests {
         let roots = list_roots(&connection);
         assert_eq!(roots.unwrap(), [foo_result, bar_result.clone()]);
 
-        let resolve_result = resolve_path(
-            &connection,
-            &"bar/baz".parse().unwrap(),
-            false,
-        );
+        let resolve_result = resolve_path(&connection, &"bar/baz".parse().unwrap(), false);
 
         assert!(resolve_result.is_ok());
         assert_eq!(
@@ -371,18 +351,10 @@ mod tests {
             vec![bar_result.clone(), baz_result.clone()]
         );
 
-        let resolve_result = resolve_path(
-            &connection,
-            &"bar/baz/bax".parse().unwrap(),
-            false,
-        );
+        let resolve_result = resolve_path(&connection, &"bar/baz/bax".parse().unwrap(), false);
         assert!(resolve_result.is_err());
 
-        let resolve_result = resolve_path(
-            &connection,
-            &"bar/baz/bax".parse().unwrap(),
-            true,
-        );
+        let resolve_result = resolve_path(&connection, &"bar/baz/bax".parse().unwrap(), true);
         assert!(resolve_result.is_ok());
 
         let bax_result = fetch_or_create_dir(
