@@ -3,7 +3,8 @@ table! {
         identity -> Binary,
         entity -> Binary,
         attribute -> Text,
-        value -> Text,
+        value_str -> Nullable<Text>,
+        value_num -> Nullable<Double>,
         immutable -> Bool,
     }
 }
