@@ -303,7 +303,7 @@ impl Query {
                                 }
                             }
                             QueryComponent::Contains(q_value) => subqueries
-                                .push(Box::new(data::value_str.like(format!("J%{}%", q_value)))),
+                                .push(Box::new(data::value_str.like(format!("S%{}%", q_value)))),
                             QueryComponent::Any => {}
                         };
 
