@@ -4,7 +4,7 @@ macro_rules! upend_insert_val {
             Entry {
                 entity: $entity.clone(),
                 attribute: String::from($attribute),
-                value: crate::database::entry::EntryValue::Value(serde_json::Value::from($value)),
+                value: crate::database::entry::EntryValue::String(String::from($value)),
             },
         )
     }};
