@@ -32,7 +32,7 @@ impl Serialize for Hash {
         S: Serializer,
     {
         serializer.serialize_str(
-            encode(
+            b58_encode(
                 Address::Hash(self.clone())
                     .encode()
                     .map_err(ser::Error::custom)?,
@@ -84,12 +84,12 @@ pub fn hash<T: AsRef<[u8]>>(input: T) -> Hash {
     Hash(Vec::from(result))
 }
 
-pub fn encode<T: AsRef<[u8]>>(vec: T) -> String {
+pub fn b58_encode<T: AsRef<[u8]>>(vec: T) -> String {
     // multibase base58
     format!("z{}", bs58::encode(vec).into_string())
 }
 
-pub fn decode<T: AsRef<str>>(string: T) -> Result<Vec<u8>> {
+pub fn b58_decode<T: AsRef<str>>(string: T) -> Result<Vec<u8>> {
     let string = string.as_ref();
     let (base, data) = string.split_at(1);
 
@@ -106,14 +106,14 @@ pub fn decode<T: AsRef<str>>(string: T) -> Result<Vec<u8>> {
 
 #[cfg(test)]
 mod tests {
-    use crate::util::hash::{decode, encode};
+    use crate::util::hash::{b58_decode, b58_encode};
 
     #[test]
     fn test_encode_decode() {
         let content = "Hello, World!".as_bytes();
 
-        let encoded = encode(content);
-        let decoded = decode(encoded);
+        let encoded = b58_encode(content);
+        let decoded = b58_decode(encoded);
 
         assert!(decoded.is_ok());
 
