@@ -7,12 +7,6 @@ export interface IEntry {
   value: IValue;
 }
 
-const model: { [key in VALUE_TYPE as string]: unknown } = {
-  String: "string",
-  Address: "address",
-  Number: 123,
-  Invalid: null,
-};
 
 export type IValue =
   | {
